Tutorials
=========

If you are new to penguins, then this is the place to start: each tutorial covers a bite-sized piece, and can be read in sequence.

To follow along with the tutorials, you will need one 1D and one 2D dataset which have already been processed in TopSpin (note that penguins only works with Bruker data). 
If you don't have some data on hand, you can `click here to download some sample data <https://github.com/yongrenjie/penguins/raw/develop/tests/nmrdata/nmrdata.zip>`_.
Unzip that directory, then open a terminal and ``cd`` into that directory.

.. toctree::
   :maxdepth: 2

   read
   plot
   customise_1d
   multiple_1d
   customise_2d
   subplots
   matplotlib

Intermediate tutorials (to be written):

* Interfacing with matplotlib
* Processing datasets (TODO) (projections, sums, magnitude mode, integration)
